==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/include/polls.inc.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

function KWL_pollResults($rid,$out) {
   $question = SqlQuery("SELECT * FROM T_PollQuestions WHERE Rid='$rid'");
   if (mysql_num_rows($question)) {
      $answers	= SqlQuery("SELECT * FROM T_PollAnswers WHERE Rid='$rid'");
      if (mysql_num_rows($answers)) {
         $Q = mysql_fetch_array($question);
			$VAR['Content'] = $out->table_start("100%",'',0,0,2).
			                "<TR><TD COLSPAN=3><B>".
                         KWL_PrepareHtml($Q['Question']).
                         "</B></TD></TR>";
         while ($A = mysql_fetch_array($answers)) {
				@$percent = 100 * $A['Votes'] / $Q['Voters'];
				@$width = (int) ($percent * 3);
				$VAR['Content'] .= "<TR><TD ALIGN=RIGHT>".
                             KWL_PrepareHtml($A['Answer']) . "&nbsp;".
                             "</TD><TD>".
                             sprintf("<IMG SRC=\"images.d/bar.gif\" WIDTH=\"$width\" HEIGHT=\"10\" ALIGN=\"bottom\" ALT=\"%.2f %%\">",$percent).
                             "</TD><TD ALIGN=RIGHT>". sprintf("%.2f", $percent) .
                             "% ($A[Votes]) &nbsp;</TD></TR>\n";
         }
         $VAR['Content'] .= "<TR><TD COLSPAN=3 ALIGN=CENTER>[ ". _VOTES . ": $Q[Voters]".
                          " | <A HREF=\"pollbooth.php\">". _LISTPOLLS ."</A> ]</TD>".
                          "</TR>". $out->table_end();
         $VAR['Heading'] = _POLLRESULTS;
         KWL_DrawMain($VAR);
      } else KWL_ErrorLog(_UNABLE_POLL);
   } else KWL_ErrorLog(_UNABLE_POLL);
}

function KWL_pollResultsBlock($rid,$align) {
   $sql = "SELECT * FROM T_PollQuestions WHERE Rid='$rid'";
   $question = SqlQuery($sql);
   if (mysql_num_rows($question)) {
      $sql	= "SELECT * FROM T_PollAnswers WHERE Rid='$rid'";
      $answers	= SqlQuery($sql);
		if (mysql_num_rows($answers)) {
         $Q = mysql_fetch_array($question);
			$VAR['Content'] = "<b>". KWL_PrepareHtml($Q['Question']) ."</b><p>";
         while ($A = mysql_fetch_array($answers)) {
            if (!$Q['Voters']) $percent = 0;
            else $percent = $A['Votes'] / $Q['Voters'];
				$VAR['Content'] .= KWL_PrepareHtml($A['Answer']) . "&nbsp;-&nbsp;<b>".
                             sprintf("%.2f", $percent * 100).
                             "%</b>&nbsp;($A[Votes])<BR>\n";
         }
         $VAR['Content'] .= "<P>";
         $c_num = SqlCount("T_Comments","TopRid",$rid);
         if (KWL_GetConf("Comments") && $c_num) {
            $VAR['Content'] .= _COMMENTS ." $c_num / ";
            $tmp = "<a href=\"pollbooth.php?poll=$rid\">"._COMMENTS."</a> | ";
         }
         $VAR['Content'] .= _VOTES . " " . $Q['Voters'] ."<BR>".
                          "<div align=right>[ $tmp<a href=\"pollbooth.php\">" . _MOREPOLLS . "</a> ]</div>\n";
         $VAR['Display'] = $align;
         $VAR['Heading'] = _POLLRESULTS;
			KWL_DrawBlock($VAR);
      } else KWL_ErrorLog(_UNABLE_POLL);
   } else KWL_ErrorLog(_UNABLE_POLL);
}

function KWL_pollVote($rid,$type='',$align='') {
   
   $out = new KWL_Html;
   $sql	= "SELECT Question FROM T_PollQuestions WHERE Rid='$rid'";
   $question = SqlQuery($sql);
	if (mysql_num_rows($question)) {
      $sql	= "SELECT Answer,Aid FROM T_PollAnswers WHERE Rid='$rid'";
      $answers	= SqlQuery($sql);
      if (mysql_num_rows($answers)) {
         $Q = mysql_fetch_array($question);
         $VAR['Heading'] = KWL_GetConf("SiteName") . _POLLS;
         $VAR['Content'] = $out->form_start("pollbooth.php","Vote").
                         $out->input_form("hidden","poll","$rid").
                         "<b>". KWL_PrepareHtml($Q['Question']) ."</b><br>";
         while ($A = mysql_fetch_array($answers)) {
            $VAR['Content'] .= $out->radio("aid",array( "$A[Aid]" => "$A[Answer]" )) . "<br>";
			}
         $VAR['Content'] .= $out->input_form("submit",'',_VOTE).
                          " [ <a href=\"pollbooth.php?poll=$rid&aid=-1\">". _RESULTS ."</a>".
                          " | <a href= \"pollbooth.php\">". _POLLS ."</a> ] ".
                          $out->form_end();
			if (KWL_GetConf("admin_login")) {
            $VAR['Content'] .= KWL_AdminLinki("T_PollQuestions",$rid,$_SERVER['PHP_SELF']);
         }
         if ($type == "block") {
            $VAR['Display'] = $align;
            KWL_DrawBlock($VAR);
         } else {
            KWL_DrawMain($VAR);
         }
      } else KWL_ErrorLog(_UNABLE_POLL);
   } else KWL_ErrorLog(_UNABLE_POLL);
}

function KWL_doVote($Rid,$Aid) {
   $sql	= "UPDATE T_PollQuestions SET Voters = Voters + 1 WHERE Rid = '$Rid'";
   if (!SqlQuery($sql)) KWL_ErrorLog(_UNABLE_POLL);
   $sql	= "UPDATE T_PollAnswers SET Votes = Votes + 1 WHERE Rid = '$Rid' AND Aid = '$Aid'";
   if (!SqlQuery($sql)) KWL_ErrorLog(_UNABLE_POLL);
   KWL_Redirect("pollbooth.php?poll=$Rid&aid=-1",1);
}

function KWL_pollList($out) {
   $question = SqlQuery("SELECT * FROM T_PollQuestions ORDER BY BirthStamp DESC");
   if (mysql_num_rows($question)) {
      $VAR['Content'] = $out->table_start("100%",'',1,0,3).
		                "<tr><th>". _QUESTION ."</th>".
                      "<th>". _VOTES ."</th>".
                      "<th>". _COMMENTS ."</th>".
                      "<th>". _POLL_STARTED ."</th></tr>\n";
      while ($Q = mysql_fetch_array($question)) {
			$VAR['Content'] .= "<tr><td>".
            "<a href=\"pollbooth.php?poll=$Q[Rid]\"><b>". 
            KWL_PrepareHtml($Q['Question']) ."</b></a>".
            " - [<a href=\"pollbooth.php?poll=$Q[Rid]&aid=-1\">". _RESULTS ."</a>]</td>".
            "<td align=center>". $Q['Voters'] ."</td>".
            "<td align=center>". SqlCount("T_Comments","TopRid",$Q['Rid']) ."</td>".
            "<td align=right>". KWL_DateFormat($Q['BirthStamp'],"%Y-%b-%d") .
            "</td></tr>\n";
		}
		$VAR['Content'] .= $out->table_end();
   } else {
      $VAR['Content'] = _NOPOLLS;
   }
   $VAR['Heading'] = _LISTPOLLS;
   KWL_DrawMain($VAR);
}
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/include/polls.inc.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

function KWL_pollResults($rid,$out) {
   $question = SqlQuery("SELECT * FROM T_PollQuestions WHERE Rid='$rid'");
   if (mysql_num_rows($question)) {
      $answers	= SqlQuery("SELECT * FROM T_PollAnswers WHERE Rid='$rid'");
      if (mysql_num_rows($answers)) {
         $Q = mysql_fetch_array($question);
			$VAR['Content'] = $out->table_start("100%",'',0,0,2).
			                "<tr><td colspan=\"3\"><b>".
                         KWL_PrepareHtml($Q['Question']).
                         "</b></td></tr>";
         while ($A = mysql_fetch_array($answers)) {
				@$percent = 100 * $A['Votes'] / $Q['Voters'];
				@$width = (int) ($percent * 3);
				$VAR['Content'] .= "<tr><td align=\"right\">".
                             KWL_PrepareHtml($A['Answer']) . "&nbsp;".
                             "</td><td>".
                             sprintf("<img src=\"images.d/bar.gif\" width=\"$width\" height=\"10\" align=\"bottom\" alt=\"%.2f %%\" />",$percent).
                             "</td><td align=\"right\">". sprintf("%.2f", $percent) .
                             "% ($A[Votes]) &nbsp;</td></tr>\n";
         }
         $VAR['Content'] .= "<tr><td colspan=\"3\" align=\"center\">[ ". _VOTES . ": $Q[Voters]".
                          " | <a href=\"pollbooth.php\">". _LISTPOLLS ."</a> ]</td>".
                          "</tr>". $out->table_end();
         $VAR['Heading'] = _POLLRESULTS;
         KWL_DrawMain($VAR);
      } else KWL_ErrorLog(_UNABLE_POLL);
   } else KWL_ErrorLog(_UNABLE_POLL);
}

function KWL_pollResultsBlock($rid,$align) {
   $sql = "SELECT * FROM T_PollQuestions WHERE Rid='$rid'";
   $question = SqlQuery($sql);
   if (mysql_num_rows($question)) {
      $sql	= "SELECT * FROM T_PollAnswers WHERE Rid='$rid'";
      $answers	= SqlQuery($sql);
		if (mysql_num_rows($answers)) {
         $Q = mysql_fetch_array($question);
			$VAR['Content'] = "<b>". KWL_PrepareHtml($Q['Question']) ."</b><p>";
         while ($A = mysql_fetch_array($answers)) {
            if (!$Q['Voters']) $percent = 0;
            else $percent = $A['Votes'] / $Q['Voters'];
				$VAR['Content'] .= KWL_PrepareHtml($A['Answer']) . "&nbsp;-&nbsp;<b>".
                             sprintf("%.2f", $percent * 100).
                             "%</b>&nbsp;($A[Votes])<BR>\n";
         }
         $VAR['Content'] .= "<p />";
         $c_num = SqlCount("T_Comments","TopRid",$rid);
         if (KWL_GetConf("Comments") && $c_num) {
            $VAR['Content'] .= _COMMENTS ." $c_num / ";
            $tmp = "<a href=\"pollbooth.php?poll=$rid\">"._COMMENTS."</a> | ";
         }
         $VAR['Content'] .= _VOTES . " " . $Q['Voters'] ."<br />".
                          "<div align=\"right\">[ $tmp<a href=\"pollbooth.php\">" . _MOREPOLLS . "</a> ]</div>\n";
         $VAR['Display'] = $align;
         $VAR['Heading'] = _POLLRESULTS;
			KWL_DrawBlock($VAR);
      } else KWL_ErrorLog(_UNABLE_POLL);
   } else KWL_ErrorLog(_UNABLE_POLL);
}

function KWL_pollVote($rid,$type='',$align='') {
   
   $out = new KWL_Html;
   $sql	= "SELECT Question FROM T_PollQuestions WHERE Rid='$rid'";
   $question = SqlQuery($sql);
	if (mysql_num_rows($question)) {
      $sql	= "SELECT Answer,Aid FROM T_PollAnswers WHERE Rid='$rid'";
      $answers	= SqlQuery($sql);
      if (mysql_num_rows($answers)) {
         $Q = mysql_fetch_array($question);
         $VAR['Heading'] = KWL_GetConf("SiteName") . _POLLS;
         $VAR['Content'] = $out->form_start("pollbooth.php","Vote").
                         $out->input_form("hidden","poll","$rid").
                         "<b>". KWL_PrepareHtml($Q['Question']) ."</b><br />";
         while ($A = mysql_fetch_array($answers)) {
            $VAR['Content'] .= $out->radio("aid",array( "$A[Aid]" => "$A[Answer]" )) . "<br>";
			}
         $VAR['Content'] .= $out->input_form("submit",'',_VOTE).
                          " [ <a href=\"pollbooth.php?poll=$rid&aid=-1\">". _RESULTS ."</a>".
                          " | <a href= \"pollbooth.php\">". _POLLS ."</a> ] ".
                          $out->form_end();
			if (KWL_GetConf("admin_login")) {
            $VAR['Content'] .= KWL_AdminLinki("T_PollQuestions",$rid,$_SERVER['PHP_SELF']);
         }
         if ($type == "block") {
            $VAR['Display'] = $align;
            KWL_DrawBlock($VAR);
         } else {
            KWL_DrawMain($VAR);
         }
      } else KWL_ErrorLog(_UNABLE_POLL);
   } else KWL_ErrorLog(_UNABLE_POLL);
}

function KWL_doVote($Rid,$Aid) {
   $sql	= "UPDATE T_PollQuestions SET Voters = Voters + 1 WHERE Rid = '$Rid'";
   if (!SqlQuery($sql)) KWL_ErrorLog(_UNABLE_POLL);
   $sql	= "UPDATE T_PollAnswers SET Votes = Votes + 1 WHERE Rid = '$Rid' AND Aid = '$Aid'";
   if (!SqlQuery($sql)) KWL_ErrorLog(_UNABLE_POLL);
   KWL_Redirect("pollbooth.php?poll=$Rid&aid=-1",1);
}

function KWL_pollList($out) {
   $question = SqlQuery("SELECT * FROM T_PollQuestions ORDER BY BirthStamp DESC");
   if (mysql_num_rows($question)) {
      $VAR['Content'] = $out->table_start("100%",'',1,0,3).
		                "<tr><th>". _QUESTION ."</th>".
                      "<th>". _VOTES ."</th>".
                      "<th>". _COMMENTS ."</th></tr>\n";
      while ($Q = mysql_fetch_array($question)) {
			$VAR['Content'] .= "<tr><td>".
            "<a href=\"pollbooth.php?poll=$Q[Rid]\"><b>". 
            KWL_PrepareHtml($Q['Question']) ."</b></a>".
            " - [<a href=\"pollbooth.php?poll=$Q[Rid]&aid=-1\">". _RESULTS ."</a>]</td>".
            "<td align=center>". $Q['Voters'] ."</td>".
            "<td align=center>". SqlCount("T_Comments","TopRid",$Q['Rid']) ."</td></tr>\n";
		}
		$VAR['Content'] .= $out->table_end();
   } else {
      $VAR['Content'] = _NOPOLLS;
   }
   $VAR['Heading'] = _LISTPOLLS;
   KWL_DrawMain($VAR);
}
?>
